Class: Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1BasicLevel
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1BasicLevel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1p5beta1/classes.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb
Overview
BasicLevel is an AccessLevel using a set of recommended features.
Instance Attribute Summary collapse
-
#combining_function ⇒ String
How the
conditionslist should be combined to determine if a request is granted thisAccessLevel. -
#conditions ⇒ Array<Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1Condition>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1BasicLevel
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1BasicLevel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1BasicLevel
Returns a new instance of GoogleIdentityAccesscontextmanagerV1BasicLevel.
1194 1195 1196 |
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1194 def initialize(**args) update!(**args) end |
Instance Attribute Details
#combining_function ⇒ String
How the conditions list should be combined to determine if a request is
granted this AccessLevel. If AND is used, each Condition in conditions
must be satisfied for the AccessLevel to be applied. If OR is used, at least
one Condition in conditions must be satisfied for the AccessLevel to be
applied. Default behavior is AND.
Corresponds to the JSON property combiningFunction
1187 1188 1189 |
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1187 def combining_function @combining_function end |
#conditions ⇒ Array<Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1Condition>
Required. A list of requirements for the AccessLevel to be granted.
Corresponds to the JSON property conditions
1192 1193 1194 |
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1192 def conditions @conditions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1199 1200 1201 1202 |
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1199 def update!(**args) @combining_function = args[:combining_function] if args.key?(:combining_function) @conditions = args[:conditions] if args.key?(:conditions) end |