Class: Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1p5beta1/classes.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb

Overview

Specifies how APIs are allowed to communicate within the Service Perimeter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices

Returns a new instance of GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices.



2080
2081
2082
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_service_patternsArray<Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1ServicePattern>

Specifies which Google services are allowed to be accessed from VPC networks in the service perimeter. Corresponds to the JSON property allowedServicePatterns



2058
2059
2060
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2058

def allowed_service_patterns
  @allowed_service_patterns
end

#allowed_servicesArray<String>

The list of APIs usable within the Service Perimeter. Must be empty unless ' enable_restriction' is True. You can specify a list of individual services, as well as include the 'RESTRICTED-SERVICES' value, which automatically includes all of the services protected by the perimeter. Corresponds to the JSON property allowedServices

Returns:

  • (Array<String>)


2066
2067
2068
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2066

def allowed_services
  @allowed_services
end

#enable_restrictionBoolean Also known as: enable_restriction?

Whether to restrict API calls within the Service Perimeter to the list of APIs specified in 'allowed_services'. Corresponds to the JSON property enableRestriction

Returns:

  • (Boolean)


2072
2073
2074
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2072

def enable_restriction
  @enable_restriction
end

#service_patterns_enforcement_scopesArray<String>

Defines the enforcement scopes of service patterns. Corresponds to the JSON property servicePatternsEnforcementScopes

Returns:

  • (Array<String>)


2078
2079
2080
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2078

def service_patterns_enforcement_scopes
  @service_patterns_enforcement_scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2085
2086
2087
2088
2089
2090
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2085

def update!(**args)
  @allowed_service_patterns = args[:allowed_service_patterns] if args.key?(:allowed_service_patterns)
  @allowed_services = args[:allowed_services] if args.key?(:allowed_services)
  @enable_restriction = args[:enable_restriction] if args.key?(:enable_restriction)
  @service_patterns_enforcement_scopes = args[:service_patterns_enforcement_scopes] if args.key?(:service_patterns_enforcement_scopes)
end