Class: Google::Apis::CloudassetV1p5beta1::ListAssetsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1p5beta1/classes.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb

Overview

ListAssets response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAssetsResponse

Returns a new instance of ListAssetsResponse.



2167
2168
2169
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetsArray<Google::Apis::CloudassetV1p5beta1::Asset>

Assets. Corresponds to the JSON property assets



2153
2154
2155
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2153

def assets
  @assets
end

#next_page_tokenString

Token to retrieve the next page of results. It expires 72 hours after the page token for the first page is generated. Set to empty if there are no remaining results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2160
2161
2162
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2160

def next_page_token
  @next_page_token
end

#read_timeString

Time the snapshot was taken. Corresponds to the JSON property readTime

Returns:

  • (String)


2165
2166
2167
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2165

def read_time
  @read_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2172
2173
2174
2175
2176
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2172

def update!(**args)
  @assets = args[:assets] if args.key?(:assets)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @read_time = args[:read_time] if args.key?(:read_time)
end