Class: Google::Apis::CloudassetV1p5beta1::Resource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1p5beta1/classes.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb

Overview

A representation of a Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Resource

Returns a new instance of Resource.



2200
2201
2202
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataHash<String,Object>

The content of the resource, in which some sensitive fields are removed and may not be present. Corresponds to the JSON property data

Returns:

  • (Hash<String,Object>)


2159
2160
2161
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2159

def data
  @data
end

#discovery_document_uriString

The URL of the discovery document containing the resource's JSON schema. Example: https://www.googleapis.com/discovery/v1/apis/compute/v1/rest This value is unspecified for resources that do not have an API based on a discovery document, such as Cloud Bigtable. Corresponds to the JSON property discoveryDocumentUri

Returns:

  • (String)


2167
2168
2169
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2167

def discovery_document_uri
  @discovery_document_uri
end

#discovery_nameString

The JSON schema name listed in the discovery document. Example: Project This value is unspecified for resources that do not have an API based on a discovery document, such as Cloud Bigtable. Corresponds to the JSON property discoveryName

Returns:

  • (String)


2174
2175
2176
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2174

def discovery_name
  @discovery_name
end

#parentString

The full name of the immediate parent of this resource. See Resource Names for more information. For Google Cloud assets, this value is the parent resource defined in the IAM policy hierarchy. Example: //cloudresourcemanager.googleapis.com/ projects/my_project_123 For third-party assets, this field may be set differently. Corresponds to the JSON property parent

Returns:

  • (String)


2185
2186
2187
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2185

def parent
  @parent
end

#resource_urlString

The REST URL for accessing the resource. An HTTP GET request using this URL returns the resource itself. Example: https://cloudresourcemanager.googleapis. com/v1/projects/my-project-123 This value is unspecified for resources without a REST API. Corresponds to the JSON property resourceUrl

Returns:

  • (String)


2193
2194
2195
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2193

def resource_url
  @resource_url
end

#versionString

The API version. Example: "v1". Corresponds to the JSON property version

Returns:

  • (String)


2198
2199
2200
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2198

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2205
2206
2207
2208
2209
2210
2211
2212
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 2205

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @discovery_document_uri = args[:discovery_document_uri] if args.key?(:discovery_document_uri)
  @discovery_name = args[:discovery_name] if args.key?(:discovery_name)
  @parent = args[:parent] if args.key?(:parent)
  @resource_url = args[:resource_url] if args.key?(:resource_url)
  @version = args[:version] if args.key?(:version)
end