Class: Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1EgressSource
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1EgressSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1p5beta1/classes.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb
Overview
The source that EgressPolicy authorizes access from inside the ServicePerimeter to somewhere outside the ServicePerimeter boundaries.
Instance Attribute Summary collapse
-
#access_level ⇒ String
An AccessLevel resource name that allows protected resources inside the ServicePerimeters to access outside the ServicePerimeter boundaries.
-
#psc_endpoint ⇒ Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint
Specifies the PSC an API call refers to.
-
#resource ⇒ String
A Google Cloud resource from the service perimeter that you want to allow to access data outside the perimeter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1EgressSource
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1EgressSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1EgressSource
Returns a new instance of GoogleIdentityAccesscontextmanagerV1EgressSource.
1517 1518 1519 |
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_level ⇒ String
An AccessLevel resource name that allows protected resources inside the
ServicePerimeters to access outside the ServicePerimeter boundaries.
AccessLevels listed must be in the same policy as this ServicePerimeter.
Referencing a nonexistent AccessLevel will cause an error. If an AccessLevel
name is not specified, only resources within the perimeter can be accessed
through Google Cloud calls with request origins within the perimeter. Example:
accessPolicies/MY_POLICY/accessLevels/MY_LEVEL. If a single * is specified
for access_level, then all EgressSources will be allowed.
Corresponds to the JSON property accessLevel
1502 1503 1504 |
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1502 def access_level @access_level end |
#psc_endpoint ⇒ Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint
Specifies the PSC an API call refers to.
Corresponds to the JSON property pscEndpoint
1507 1508 1509 |
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1507 def psc_endpoint @psc_endpoint end |
#resource ⇒ String
A Google Cloud resource from the service perimeter that you want to allow to
access data outside the perimeter. This field supports only projects. The
project format is projects/project_number`. You can't use*in this field
to allow all Google Cloud resources.
Corresponds to the JSON propertyresource`
1515 1516 1517 |
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1515 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1522 1523 1524 1525 1526 |
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1522 def update!(**args) @access_level = args[:access_level] if args.key?(:access_level) @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint) @resource = args[:resource] if args.key?(:resource) end |