Class: Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1IngressFrom

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1p5beta1/classes.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb,
lib/google/apis/cloudasset_v1p5beta1/representations.rb

Overview

Defines the conditions under which an IngressPolicy matches a request. Conditions are based on information about the source of the request. The request must satisfy what is defined in sources AND identity related fields in order to match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressFrom

Returns a new instance of GoogleIdentityAccesscontextmanagerV1IngressFrom.



1581
1582
1583
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identitiesArray<String>

A list of identities that are allowed access through [IngressPolicy]. Identities can be an individual user, service account, Google group, third- party identity, or agent identity. For the list of supported identity types, see https://docs.cloud.google.com/vpc-service-controls/docs/supported- identities. Corresponds to the JSON property identities

Returns:

  • (Array<String>)


1567
1568
1569
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1567

def identities
  @identities
end

#identity_typeString

Specifies the type of identities that are allowed access from outside the perimeter. If left unspecified, then members of identities field will be allowed access. Corresponds to the JSON property identityType

Returns:

  • (String)


1574
1575
1576
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1574

def identity_type
  @identity_type
end

#sourcesArray<Google::Apis::CloudassetV1p5beta1::GoogleIdentityAccesscontextmanagerV1IngressSource>

Sources that this IngressPolicy authorizes access from. Corresponds to the JSON property sources



1579
1580
1581
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1579

def sources
  @sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1586
1587
1588
1589
1590
# File 'lib/google/apis/cloudasset_v1p5beta1/classes.rb', line 1586

def update!(**args)
  @identities = args[:identities] if args.key?(:identities)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
  @sources = args[:sources] if args.key?(:sources)
end